#!/usr/bin/python3
import sys
import os
from datetime import datetime, timezone

from insights_protocol import StepBase, ExchangeDataHolder

import pyowm
import aiohttp

owm_apikey = os.environ["OWM_APIKEY"]
owm_place = os.environ.get("OWM_PLACE") or "Markdorf, DE"

class AsyncGetRequestOWM(StepBase):
    # Called for every input
    async def invoke(self, exchange_data_holder: ExchangeDataHolder) -> ExchangeDataHolder:
        api_url = 'https://api.openweathermap.org/data/2.5/weather'
        parameters = {
                         'q': owm_place,
                         'appid': owm_apikey,
                         'units': 'metric',
                     }
        timeout = aiohttp.ClientTimeout(total=20)
        async with aiohttp.ClientSession(timeout=timeout, trust_env=True) as session:
            response = await session.get(api_url, params=parameters)
            response_json = await response.json()
            weather = response_json.get('main') or {}
        
            result = {
                          'ts': datetime.now(tz=timezone.utc),
                          'v':  weather.get('temp'),
                          'u': '°C',
                     }
            return exchange_data_holder._replace(documents=[result])
        
if __name__ == "__main__":
    input = sys.stdin.buffer
    output = sys.stdout.buffer
    sys.stdout = sys.stderr  # make any print in code going to stderr
    AsyncGetRequestOWM(input, output).process_stream()