#!/usr/bin/python
import sys, os
from bson.json_util import dumps, loads, RELAXED_JSON_OPTIONS
from datetime import datetime, timezone

import pyowm

owm_apikey = os.environ["OWM_APIKEY"]
owm_place = os.environ.get("OWM_PLACE") or "Markdorf, DE"

for line in sys.stdin:
    input_data_holder = loads(line)
    
    # Get some extra data to enrich with
    owm = pyowm.OWM(owm_apikey)
    request_ts = datetime.now(tz=timezone.utc)
    sf = owm.weather_at_place(owm_place)
    weather = sf.get_weather()
    owm_temp = float(weather.get_temperature('celsius')['temp'])
    
    for doc in input_data_holder.get('documents'):
        metadata = doc.get('metaData') or {}
        doc['metaData'] = metadata
        metadata['processedAt'] = datetime.now(tz=timezone.utc)
        
        payload = doc.get('payload') or {}
        doc['payload'] = payload
        
        payload["temp"] =  {
                                'loc': owm_place,
                                'v': owm_temp,
                                'ts': request_ts,
                           }

    print(dumps(input_data_holder, json_options=RELAXED_JSON_OPTIONS))