#!/usr/bin/python3
from insights_protocol import StepBase, ExchangeDataHolder
from bson import json_util
import sys

class MyInsightsPythonStep(StepBase):
    # Called for every input
    async def invoke(self, exchange_data_holder: ExchangeDataHolder) -> ExchangeDataHolder:
        print("\nStart processing " + str(exchange_data_holder))

        first_doc = exchange_data_holder.documents[0]

        # Decode payload, in case it was not decoded by a previous parser step
        if type(first_doc['payload']) is bytes:
            first_doc['payload'] = json_util.loads(first_doc['payload'])

        # modify the data
        first_doc['payload']["addedValue"] = "my python invoked and attached new value"

        # error message and trace should show up in the Insights Console
        if (first_doc.get('metaData') or {}).get("hasError", None):
            # pass
            raise Exception('My Error')
            # also possible is exchange_data_holder.error = "Error"

        print("processed %s\n" % exchange_data_holder.id)

        return exchange_data_holder

if __name__ == "__main__":
    input = sys.stdin.buffer
    output = sys.stdout.buffer
    sys.stdout = sys.stderr  # make any print in code going to stderr
    MyInsightsPythonStep(input, output).process_stream()
